\name{proc.trec.A}
\alias{proc.trec.A}
\title{Optimization wrapper for autosomes, total read counts (TReC) only}
\description{
  Performs optimization of the likelihood for TReC only model and tests with lrt test several hypotheses:
  additive, parent of origin, dominance, sex, sex specific additive, sex specific parent of origin, sex specific dominance effects.
}
\usage{
proc.trec.A(index,y,kappas=NULL,geneids=rownames(y),hessian=FALSE)}
\arguments{
  \item{index}{vector defining the cross of the mouse, AB_female=1,BA_female=2,AA_female=3,BB_female=4,AB_male=5,BA_male=6,AA_male=7,BB_male=8.
  If mice are of only one sex, AB=1,BA=2,AA=3,BB=4.}
  \item{y}{matrix of TReC counts.}
  \item{kappas}{Offset parameter, given as overall TReC for the mouse.
  Since it may be better to calculate these values even using genes one decides not to estimate: low counts genes, pseudogenes, one may provide them as a paramter.
  If the value is not provided, kappas will be calculated based on a \bold{y} matrix provided}
  \item{geneids}{ids of genes, if not provided, rownames of the matrix \bold{y} will be used}
  \item{hessian}{a flag whether Hessian matrix for these genes should be calculated, by default set to FALSE}
}
\value{
  a list of following matrices (if there is only one sex, only the relevant tests and matrices are outputed) :
  \item{pvals}{matrix of p-values from description for each gene corresponding row}
  \item{coef.full}{matrix of full model fit coefficients, -log(likelihood at these coefficients),phi^-1, theta (2 overdispersion parameters used)}  
  \item{coef.add}{matrix of additive restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.poo}{matrix of parent of origin restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.dom}{matrix of dominance restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.sex}{matrix of sex restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.add}{matrix of sex specific additive restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.poo}{matrix of sex specific parent of origin restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.dom}{matrix of sex specific dominance restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{errorlist}{a list of errors}
  \item{hess.lst}{a list of heassian matrices, if parameter \bold{hessian} is set to TRUE}  
}
\author{ Vasyl Zhabotynsky vasyl@unc.edu }
\keyword{ methods }
