\name{proc.trec.X}
\alias{proc.trec.X}
\title{Optimization wrapper for X chromosome, total read counts (TReC) only}
\description{
  Performs optimization of the likelihood for TReC only model and tests with lrt test several hypotheses:
  additive, parent of origin, dominance, sex, sex specific additive, male dominance deviation effects.
}
\usage{
proc.trec.X(index,y,kappas=NULL,tausB=NULL,genes.switch="ENSMUSG00000086503",geneids=rownames(y),hessian=FALSE)}
\arguments{
  \item{index}{vector defining the cross of the mouse, AB_female=1,BA_female=2,AA_female=3,BB_female=4,AB_male=5,BA_male=6,AA_male=7,BB_male=8.}
  \item{y}{matrix of TReC counts.}
  \item{kappas}{Offset parameter, given as overall TReC for the mouse.
  Since it may be better to calculate these values even using genes one decides not to estimate: low counts genes, pseudogenes, one may provide them as a paramter.
  If the value is not provided, kappas will be calculated based on a \bold{y} matrix provided}
  \item{tausB}{\emph{Xce} effect: expression of allele B relative to the overall allele specific count for each mouse. Use some allele specific counts to estimate the effect.
  If no values submitted, the \emph{Xce} effect of 50\% will be used. It is not recommended, since it would not estimate additive effect right, if no allele specific counts are available, try to use literature estimates.}
  \item{genes.switch}{vector of geneids you want to have \emph{Xce} effect to be switched to 1-tausB, for example, it has to be done for \emph{Xist}, by default ensembl gene id for this gene is provided}
  \item{geneids}{ids of genes, if not provided, rownames of the matrix \bold{y} will be used}
  \item{hessian}{a flag whether Hessian matrix for these genes should be calculated, by default set to FALSE}
}
\value{
  a list of following matrices (if there is only one sex, only the relevant tests and matrices are outputed) :
  \item{pvals}{matrix of p-values from description for each gene corresponding row}
  \item{coef.full}{matrix of full model fit coefficients, -log(likelihood at these coefficients),phi^-1, theta (2 overdispersion parameters used)}  
  \item{coef.add}{matrix of additive restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.poo}{matrix of parent of origin restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.dom}{matrix of dominance restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.sex}{matrix of sex restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.sex.add}{matrix of sex specific additive restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.dev.dom}{matrix of dominance deviation for male restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{errorlist}{a list of errors}
  \item{hess.lst}{a list of heassian matrices, if parameter \bold{hessian} is set to TRUE}  
}
\author{ Vasyl Zhabotynsky vasyl@unc.edu }
\keyword{ methods }
