\name{proc.trecase.A}
\alias{proc.trecase.A}
\title{Optimization wrapper for autosomes, maximizing the joint model of total (TReC) and allele specific (ASE) counts}
\description{
  Performs optimization of the joint likelihood of TReC and ASE counts and tests with lrt test several hypotheses:
  additive, parent of origin, dominance, consistency of TreC and ASE additive effect, ASE only additive effect, 
  sex, sex specific additive, sex specific parent of origin, sex specific dominance effects.
}
\usage{
proc.trecase.A(index,y,n,n0B,kappas=NULL,geneids=rownames(y),hessian=FALSE)}
\arguments{
  \item{index}{vector defining the cross of the mouse, AB_female=1,BA_female=2,AA_female=3,BB_female=4,AB_male=5,BA_male=6,AA_male=7,BB_male=8.
  If mice are of only one sex, AB=1,BA=2,AA=3,BB=4.}
  \item{y}{matrix of TReC counts. Note, the expected input assumes that inbred mice will be in the last columns of the table, after the last F1 mouse.}
  \item{n}{matrix of ASE counts for corresponding F1 mouse (classes 1,2,5,6) for corresponding genes.
  Note, it is expected that these mice are coming in the same order as F1 mice for TReC matrix above.}  
  \item{n0B}{matrix of ASE counts belonging for allele B, for correponding genes and mice as in \bold{n}.}  
  \item{kappas}{Offset parameter, given as log(overall TReC) for each mouse. 
  Since it may be better to calculate these values even using genes one decides not to estimate: low counts genes, pseudogenes, one may provide them as a paramter.
  If the value is not provided, kappas will be calculated based on a \bold{y} matrix provided}
  \item{geneids}{ids of genes, if not provided, rownames of the matrix \bold{y} will be used}
  \item{hessian}{a flag whether Hessian matrix for these genes should be calculated, by default set to FALSE}
}
\value{
  a list of following matrices (if there is only one sex, only the relevant tests and matrices are outputed) :
  \item{pvals}{matrix of p-values from description for each gene corresponding row}
  \item{coef.full}{matrix of full model fit coefficients, -log(likelihood at these coefficients),phi^-1, theta (2 overdispersion parameters used)}  
  \item{coef.add}{matrix of additive restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.poo}{matrix of parent of origin restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.dom}{matrix of dominance restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.same}{matrix of TReC=ASE additive restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.ase.add}{matrix of ASE additive restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.sex}{matrix of sex restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.add}{matrix of sex specific additive restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.poo}{matrix of sex specific parent of origin restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{coef.dom}{matrix of sex specific dominance restricted fit coefficients, -log(likelihood at these coefficients),phi^-1, theta}
  \item{errorlist}{a list of errors}
  \item{hess.lst}{a list of heassian matrices, if parameter \bold{hessian} is set to TRUE}  
}
\author{ Vasyl Zhabotynsky vasyl@unc.edu }
\keyword{ methods }
